==> jc-1.4.0.tar.gz: soot/jimple/toolkits/base/Aggregator.h <==
// public class soot.jimple.toolkits.base.Aggregator

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class a76a7734eb62f430 soot_BodyTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class 325d19e063922d8 soot_jimple_toolkits_base_Aggregator

// header file dependencies
// @dep_header soot_BodyTransformer

#include "soot/BodyTransformer.h"

#ifndef _JC_soot_jimple_toolkits_base_Aggregator_H_
#define _JC_soot_jimple_toolkits_base_Aggregator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_Unit$object;
struct _jc_soot_jimple_StmtBody$object;
struct _jc_soot_jimple_toolkits_base_Aggregator$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_base_Aggregator$sub_refs	_jc_soot_jimple_toolkits_base_Aggregator$sub_refs;
typedef struct _jc_soot_jimple_toolkits_base_Aggregator$sub_nonrefs	_jc_soot_jimple_toolkits_base_Aggregator$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_base_Aggregator$refs	_jc_soot_jimple_toolkits_base_Aggregator$refs;
typedef struct _jc_soot_jimple_toolkits_base_Aggregator$nonrefs	_jc_soot_jimple_toolkits_base_Aggregator$nonrefs;
typedef struct _jc_soot_jimple_toolkits_base_Aggregator$object	_jc_soot_jimple_toolkits_base_Aggregator$object;

typedef const struct _jc_soot_jimple_toolkits_base_Aggregator$vmethods	_jc_soot_jimple_toolkits_base_Aggregator$vmethods;
typedef const struct _jc_soot_jimple_toolkits_base_Aggregator$vtable	_jc_soot_jimple_toolkits_base_Aggregator$vtable;
typedef const struct _jc_soot_jimple_toolkits_base_Aggregator$vtype	_jc_soot_jimple_toolkits_base_Aggregator$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_base_Aggregator$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_base_Aggregator$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_base_Aggregator$method$internalTransform$9abd4924859b68a3(_jc_env *, struct _jc_soot_jimple_toolkits_base_Aggregator$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_base_Aggregator$method_info$internalTransform$9abd4924859b68a3;

// Static methods
extern jboolean _jc_soot_jimple_toolkits_base_Aggregator$method$internalAggregate$6c7d46b1d075b7f3(_jc_env *, struct _jc_soot_jimple_StmtBody$object *, struct _jc_object *, jboolean);
extern jboolean _jc_soot_jimple_toolkits_base_Aggregator$method$isSimpleCopy$03e739a4aa780f41(_jc_env *, struct _jc_object *);
extern struct _jc_soot_jimple_toolkits_base_Aggregator$object *_jc_soot_jimple_toolkits_base_Aggregator$method$v$6102ffd5bb704def(_jc_env *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_base_Aggregator$vmethods {
	void	(*internalTransform$9abd4924859b68a3)(_jc_env *, struct _jc_soot_jimple_toolkits_base_Aggregator$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_base_Aggregator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_BodyTransformer$vmethods	soot_BodyTransformer;
	_jc_soot_jimple_toolkits_base_Aggregator$vmethods	soot_jimple_toolkits_base_Aggregator;
};

// Vtype
struct _jc_soot_jimple_toolkits_base_Aggregator$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_base_Aggregator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_base_Aggregator$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_base_Aggregator$refs {
    _jc_soot_jimple_toolkits_base_Aggregator$sub_refs	soot_jimple_toolkits_base_Aggregator;
    _jc_soot_BodyTransformer$sub_refs	soot_BodyTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_base_Aggregator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_base_Aggregator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_BodyTransformer$sub_nonrefs	soot_BodyTransformer;
    _jc_soot_jimple_toolkits_base_Aggregator$sub_nonrefs	soot_jimple_toolkits_base_Aggregator;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_base_Aggregator$object {
	_jc_soot_jimple_toolkits_base_Aggregator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_base_Aggregator$vtype	*vtype;
	_jc_soot_jimple_toolkits_base_Aggregator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_base_Aggregator$vtype _jc_soot_jimple_toolkits_base_Aggregator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_base_Aggregator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_base_Aggregator$class_object;

#endif	/* _JC_soot_jimple_toolkits_base_Aggregator_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/base/Aggregator.h <==
// public class soot.jimple.toolkits.base.Aggregator

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class a76a7734eb62f430 soot_BodyTransformer
// @dep_class de5fa3182955e270 soot_Transformer
// @dep_class 325d19e063922d8 soot_jimple_toolkits_base_Aggregator

// header file dependencies
// @dep_header soot_BodyTransformer

#include "soot/BodyTransformer.h"

#ifndef _JC_soot_jimple_toolkits_base_Aggregator_H_
#define _JC_soot_jimple_toolkits_base_Aggregator_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;
struct _jc_soot_Body$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_Unit$object;
struct _jc_soot_jimple_StmtBody$object;
struct _jc_soot_jimple_toolkits_base_Aggregator$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_base_Aggregator$sub_refs	_jc_soot_jimple_toolkits_base_Aggregator$sub_refs;
typedef struct _jc_soot_jimple_toolkits_base_Aggregator$sub_nonrefs	_jc_soot_jimple_toolkits_base_Aggregator$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_base_Aggregator$refs	_jc_soot_jimple_toolkits_base_Aggregator$refs;
typedef struct _jc_soot_jimple_toolkits_base_Aggregator$nonrefs	_jc_soot_jimple_toolkits_base_Aggregator$nonrefs;
typedef struct _jc_soot_jimple_toolkits_base_Aggregator$object	_jc_soot_jimple_toolkits_base_Aggregator$object;

typedef const struct _jc_soot_jimple_toolkits_base_Aggregator$vmethods	_jc_soot_jimple_toolkits_base_Aggregator$vmethods;
typedef const struct _jc_soot_jimple_toolkits_base_Aggregator$vtable	_jc_soot_jimple_toolkits_base_Aggregator$vtable;
typedef const struct _jc_soot_jimple_toolkits_base_Aggregator$vtype	_jc_soot_jimple_toolkits_base_Aggregator$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_base_Aggregator$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_jimple_toolkits_base_Aggregator$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_base_Aggregator$method$internalTransform$9abd4924859b68a3(_jc_env *, struct _jc_soot_jimple_toolkits_base_Aggregator$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_base_Aggregator$method_info$internalTransform$9abd4924859b68a3;

// Static methods
extern jboolean _jc_soot_jimple_toolkits_base_Aggregator$method$internalAggregate$6c7d46b1d075b7f3(_jc_env *, struct _jc_soot_jimple_StmtBody$object *, struct _jc_object *, jboolean) _JC_JCNI_ATTR;
extern jboolean _jc_soot_jimple_toolkits_base_Aggregator$method$isSimpleCopy$03e739a4aa780f41(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_toolkits_base_Aggregator$object *_jc_soot_jimple_toolkits_base_Aggregator$method$v$6102ffd5bb704def(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_base_Aggregator$vmethods {
	void	(*internalTransform$9abd4924859b68a3)(_jc_env *, struct _jc_soot_jimple_toolkits_base_Aggregator$object *, struct _jc_soot_Body$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_base_Aggregator$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_Transformer$vmethods	soot_Transformer;
	_jc_soot_BodyTransformer$vmethods	soot_BodyTransformer;
	_jc_soot_jimple_toolkits_base_Aggregator$vmethods	soot_jimple_toolkits_base_Aggregator;
};

// Vtype
struct _jc_soot_jimple_toolkits_base_Aggregator$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_base_Aggregator$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_base_Aggregator$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_base_Aggregator$refs {
    _jc_soot_jimple_toolkits_base_Aggregator$sub_refs	soot_jimple_toolkits_base_Aggregator;
    _jc_soot_BodyTransformer$sub_refs	soot_BodyTransformer;
    _jc_soot_Transformer$sub_refs	soot_Transformer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_base_Aggregator$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_base_Aggregator$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_Transformer$sub_nonrefs	soot_Transformer;
    _jc_soot_BodyTransformer$sub_nonrefs	soot_BodyTransformer;
    _jc_soot_jimple_toolkits_base_Aggregator$sub_nonrefs	soot_jimple_toolkits_base_Aggregator;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_base_Aggregator$object {
	_jc_soot_jimple_toolkits_base_Aggregator$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_base_Aggregator$vtype	*vtype;
	_jc_soot_jimple_toolkits_base_Aggregator$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_base_Aggregator$vtype _jc_soot_jimple_toolkits_base_Aggregator$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_base_Aggregator, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_base_Aggregator$class_object;

#endif	/* _JC_soot_jimple_toolkits_base_Aggregator_H_ */
